@@ -17,43 +17,61 @@
  *************************************************************************************/
 
 #include "filereceiver.h"
-#include "../BlueDevilDaemon.h"
 #include "obexagent.h"
-#include "obex_agent_manager.h"
+#include "debug_p.h"
 
-#include <QDBusConnection>
-#include <QDBusPendingCall>
-#include <QDBusPendingCallWatcher>
+#include <BluezQt/PendingCall>
+#include <BluezQt/InitObexManagerJob>
 
-FileReceiver::FileReceiver(QObject* parent)
+FileReceiver::FileReceiver(QSharedPointer<BluezQt::Manager> manager, QObject *parent)
     : QObject(parent)
 {
-    qCDebug(BLUEDAEMON);
-    qDBusRegisterMetaType<QVariantMap>();
+    m_agent = new ObexAgent(manager, this);
 
-    new ObexAgent(this);
-    org::bluez::obex::AgentManager1 *agent = new org::bluez::obex::AgentManager1(QStringLiteral("org.bluez.obex"),
-                                                                                 QStringLiteral("/org/bluez/obex"),
-                                                                                 QDBusConnection::sessionBus(),
-                                                                                 this);
-
-    QDBusPendingReply <void > r = agent->RegisterAgent(QDBusObjectPath(QStringLiteral("/BlueDevil_receiveAgent")));
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(r, this);
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), SLOT(agentRegistered(QDBusPendingCallWatcher*)));
+    m_manager = new BluezQt::ObexManager(this);
+    BluezQt::InitObexManagerJob *initJob = m_manager->init();
+    initJob->start();
+    connect(initJob, &BluezQt::InitObexManagerJob::result, this, &FileReceiver::initJobResult);
 }
 
 FileReceiver::~FileReceiver()
 {
-
+    if (m_agent) {
+        qCDebug(BLUEDAEMON) << "Unregistering ObexAgent";
+        m_manager->unregisterAgent(m_agent);
+    }
 }
 
-void FileReceiver::agentRegistered(QDBusPendingCallWatcher* call)
+void FileReceiver::initJobResult(BluezQt::InitObexManagerJob *job)
 {
-    QDBusPendingReply <void > r = *call;
-    qCDebug(BLUEDAEMON) << "Error: " << r.isError();
-    if (r.isError()) {
-        qCDebug(BLUEDAEMON) << r.error().message();
+    if (job->error()) {
+        qCWarning(BLUEDAEMON) << "Error initializing ObexManager!";
+        return;
     }
 
-    call->deleteLater();
+    // Make sure to register agent when obexd starts
+    operationalChanged(m_manager->isOperational());
+    connect(m_manager, &BluezQt::ObexManager::operationalChanged, this, &FileReceiver::operationalChanged);
+}
+
+void FileReceiver::agentRegistered(BluezQt::PendingCall *call)
+{
+    if (call->error()) {
+        qCWarning(BLUEDAEMON) << "Error registering ObexAgent" << call->errorText();
+    } else {
+        qCDebug(BLUEDAEMON) << "ObexAgent registered";
+    }
+}
+
+void FileReceiver::operationalChanged(bool operational)
+{
+    qCDebug(BLUEDAEMON) << "ObexManager operational changed" << operational;
+
+    if (operational) {
+        BluezQt::PendingCall *call = m_manager->registerAgent(m_agent);
+        connect(call, &BluezQt::PendingCall::finished, this, &FileReceiver::agentRegistered);
+    } else {
+        // Attempt to start obexd
+        BluezQt::ObexManager::startService();
+    }
 }
