@@ -24,22 +24,26 @@
 #include <KAbstractFileItemActionPlugin>
 #include <KFileItemListProperties>
 
+#include "kdedbluedevil.h"
+
 class QAction;
 class QWidget;
 
 class SendFileItemAction : public KAbstractFileItemActionPlugin
 {
-Q_OBJECT
+    Q_OBJECT
+
 public:
-    SendFileItemAction(QObject* parent, const QVariantList &args);
-    virtual QList< QAction* > actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget);
+    SendFileItemAction(QObject *parent, const QVariantList&);
+    QList<QAction*> actions(const KFileItemListProperties &infos, QWidget *parent) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void deviceTriggered();
     void otherTriggered();
 
 private:
-    KFileItemListProperties m_fileItemInfos;
+    org::kde::BlueDevil *m_kded;
+    KFileItemListProperties m_infos;
 };
 
 #endif // SENDFILEITEMACTION_H
