@@ -21,17 +21,16 @@
 #ifndef _BLUEDEVILTRANSFER_H
 #define _BLUEDEVILTRANSFER_H
 
-#include <kcmodule.h>
+#include <KCModule>
 
-class SystemCheck;
-namespace Ui {
+#include <BluezQt/Manager>
+
+namespace Ui
+{
     class Transfer;
 }
-namespace BlueDevil {
-    class Adapter;
-}
 
-typedef BlueDevil::Adapter Adapter;
+class SystemCheck;
 
 class KCMBlueDevilTransfer : public KCModule
 {
@@ -39,19 +38,14 @@ class KCMBlueDevilTransfer : public KCModule
 
 public:
     KCMBlueDevilTransfer(QWidget *parent, const QVariantList&);
-    virtual ~KCMBlueDevilTransfer();
 
-    virtual void save();
 private Q_SLOTS:
-    void usableAdapterChanged(Adapter *adapter);
-    void adapterDiscoverableChanged();
-    void updateInformationState();
-    void changed(bool);
+    void initJobResult(BluezQt::InitManagerJob *job);
 
 private:
     SystemCheck *m_systemCheck;
     Ui::Transfer *m_uiTransfer;
-    bool m_restartNeeded;
+    BluezQt::Manager *m_manager;
 };
 
-#endif
+#endif // _BLUEDEVILTRANSFER_H
