@@ -27,12 +27,9 @@
 #include <QCoreApplication>
 #include <QDBusMetaType>
 
-#include <KProcess>
 #include <KLocalizedString>
 
-#include <bluedevil/bluedevil.h>
-
-using namespace BlueDevil;
+#include <BluezQt/Services>
 
 extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
@@ -56,32 +53,37 @@ KioBluetooth::KioBluetooth(const QByteArray &pool, const QByteArray &app)
 
     m_hasCurrentHost = false;
 
-    Service s;
-    s.name = i18n("Send File");
-    s.icon = QStringLiteral("edit-copy");
-    s.mimetype = QStringLiteral("application/vnd.kde.bluedevil-sendfile");
-    s.uuid = QStringLiteral("00001105-0000-1000-8000-00805F9B34FB");
-    m_supportedServices.insert(QStringLiteral("00001105-0000-1000-8000-00805F9B34FB"), s);
-    s.name = i18n("Browse Files");
-    s.icon = QStringLiteral("edit-find");
-    s.mimetype = QString();
-    s.uuid = QStringLiteral("00001106-0000-1000-8000-00805F9B34FB");
-    m_supportedServices.insert(QStringLiteral("00001106-0000-1000-8000-00805F9B34FB"), s);
+    Service sendFile;
+    sendFile.name = i18n("Send File");
+    sendFile.icon = QStringLiteral("edit-copy");
+    sendFile.mimetype = QStringLiteral("application/vnd.kde.bluedevil-sendfile");
+    sendFile.uuid = BluezQt::Services::ObexObjectPush;
 
-    if (!Manager::self()->usableAdapter()) {
-        qCDebug(BLUETOOTH) << "No available interface";
+    Service browseFiles;
+    browseFiles.name = i18n("Browse Files");
+    browseFiles.icon = QStringLiteral("edit-find");
+    browseFiles.mimetype = QString();
+    browseFiles.uuid = BluezQt::Services::ObexFileTransfer;
+
+    m_supportedServices.insert(sendFile.uuid, sendFile);
+    m_supportedServices.insert(browseFiles.uuid, browseFiles);
+
+    qCDebug(BLUETOOTH) << "Kio Bluetooth instanced!";
+
+    m_kded = new org::kde::BlueDevil(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/bluedevil"),
+                                     QDBusConnection::sessionBus());
+
+    if (!m_kded->isOnline()) {
+        qCDebug(BLUETOOTH) << "Bluetooth is offline";
         infoMessage(i18n("No Bluetooth adapters have been found."));
         return;
     }
-
-    qCDebug(BLUETOOTH) << "Kio Bluetooth instanced!";
-    m_kded = new org::kde::BlueDevil(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/bluedevil"),
-                                     QDBusConnection::sessionBus(), 0);
 }
 
 QList<KioBluetooth::Service> KioBluetooth::getSupportedServices(const QStringList &uuids)
 {
     qCDebug(BLUETOOTH) << "supported services: " << uuids;
+
     QList<Service> retValue;
     Q_FOREACH (const QString &uuid, uuids) {
         if (m_supportedServices.contains(uuid)) {
@@ -93,24 +95,34 @@ QList<KioBluetooth::Service> KioBluetooth::getSupportedServices(const QStringLis
 
 void KioBluetooth::listRemoteDeviceServices()
 {
-    m_kded->stopDiscovering();
     infoMessage(i18n("Retrieving services..."));
 
     qCDebug(BLUETOOTH) << "Listing remote devices";
-    m_currentHost = Manager::self()->usableAdapter()->deviceForAddress(m_currentHostname.replace('-', ':').toUpper());
-    m_currentHostServices = getSupportedServices(m_currentHost->UUIDs());
 
-    qCDebug(BLUETOOTH) << "Num of supported services: " << m_currentHostServices.size();
-    totalSize(m_currentHostServices.count());
+    const DeviceInfo &info = m_kded->device(m_currentHostAddress).value();
+    if (info.isEmpty()) {
+        qCDebug(BLUETOOTH) << "Invalid hostname!";
+        infoMessage(i18n("This address is unavailable."));
+        finished();
+        return;
+    }
+
+    const QList<Service> &services = getSupportedServices(info.value(QStringLiteral("UUIDs")).split(QLatin1Char(',')));
+
+    qCDebug(BLUETOOTH) << "Num of supported services: " << services.size();
+
     int i = 1;
-    Q_FOREACH (const Service &service, m_currentHostServices) {
+    totalSize(services.count());
+
+    Q_FOREACH (const Service &service, services) {
         KIO::UDSEntry entry;
         entry.insert(KIO::UDSEntry::UDS_NAME, service.uuid);
         entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, service.name);
         entry.insert(KIO::UDSEntry::UDS_ICON_NAME, service.icon);
+        entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IRGRP | S_IROTH);
 
-        //If it is browse files, act as a folder
-        if (service.uuid == QLatin1String("00001106-0000-1000-8000-00805F9B34FB")) {
+        // If it is browse files, act as a folder
+        if (service.uuid == BluezQt::Services::ObexFileTransfer) {
             QUrl obexUrl;
             obexUrl.setScheme(QStringLiteral("obexftp"));
             obexUrl.setHost(m_currentHostname.replace(QLatin1Char(':'), QLatin1Char('-')).toUpper());
@@ -118,7 +130,6 @@ void KioBluetooth::listRemoteDeviceServices()
             entry.insert(KIO::UDSEntry::UDS_URL, obexUrl.toString());
         } else {
             entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-            entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRWXU | S_IRWXG | S_IRWXO);
         }
 
         if (service.mimetype.isEmpty()) {
@@ -126,6 +137,7 @@ void KioBluetooth::listRemoteDeviceServices()
         } else {
             entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, service.mimetype);
         }
+
         listEntry(entry);
         processedSize(i++);
     }
@@ -137,11 +149,15 @@ void KioBluetooth::listRemoteDeviceServices()
 void KioBluetooth::listDevices()
 {
     qCDebug(BLUETOOTH) << "Asking kded for devices";
-    QMapDeviceInfo devices = m_kded->knownDevices().value();
+    const QMapDeviceInfo &devices = m_kded->allDevices().value();
     qCDebug(BLUETOOTH) << devices.keys();
+
     Q_FOREACH(const DeviceInfo device, devices) {
         listDevice(device);
     }
+
+    m_kded->startDiscovering(10 * 1000);
+
     infoMessage(i18n("Scanning for new devices..."));
     finished();
 }
@@ -161,11 +177,7 @@ void KioBluetooth::listDevice(const DeviceInfo device)
     entry.insert(KIO::UDSEntry::UDS_ICON_NAME, device[QStringLiteral("icon")]);
     entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IRGRP | S_IROTH);
-    if (device.contains(QStringLiteral("discovered")) && device[QStringLiteral("discovered")] == QLatin1String("true")) {
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/vnd.kde.bluedevil.device.discovered"));
-    } else {
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/vnd.kde.bluedevil.device"));
-    }
+    entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/vnd.kde.bluedevil.device"));
     listEntry(entry);
 }
 
@@ -173,8 +185,8 @@ void KioBluetooth::listDir(const QUrl &url)
 {
     qCDebug(BLUETOOTH) << "Listing..." << url;
 
-    /// Url is not used here becuase all we could care about the url is the host, and that's already
-    /// handled in @p setHost
+    // Url is not used here becuase all we could care about the url is the host, and that's already
+    // handled in @p setHost
     Q_UNUSED(url);
 
     // If we are not online (ie. there's no working bluetooth adapter), list an empty dir
@@ -207,24 +219,23 @@ void KioBluetooth::get(const QUrl &url)
     finished();
 }
 
-void KioBluetooth::setHost(const QString &constHostname, quint16 port, const QString &user,
-                           const QString &pass)
+void KioBluetooth::setHost(const QString &hostname, quint16 port, const QString &user, const QString &pass)
 {
-    qCDebug(BLUETOOTH) << "Setting host: " << constHostname;
+    qCDebug(BLUETOOTH) << "Setting host: " << hostname;
 
     // In this kio only the hostname (constHostname) is used
     Q_UNUSED(port)
     Q_UNUSED(user)
     Q_UNUSED(pass)
 
-    QString hostname = constHostname;
-    hostname = hostname.replace(QLatin1Char('-'), QLatin1Char(':')).toUpper();
     if (hostname.isEmpty()) {
         m_hasCurrentHost = false;
     } else {
         m_hasCurrentHost = true;
-        m_currentHostname = constHostname;
-        m_currentHostServices.clear();
+
+        m_currentHostname = hostname;
+        m_currentHostAddress = hostname.toUpper();
+        m_currentHostAddress.replace(QLatin1Char('-'), QLatin1Char(':'));
     }
 }
 
