@@ -17,50 +17,42 @@
 
 #include "bluewizard.h"
 #include "wizardagent.h"
-#include "pages/discoverpage.h"
-#include "pages/nopairing.h"
+#include "pages/discover.h"
+#include "pages/connect.h"
 #include "pages/legacypairing.h"
 #include "pages/legacypairingdatabase.h"
 #include "pages/keyboardpairing.h"
 #include "pages/ssppairing.h"
+#include "pages/success.h"
 #include "pages/fail.h"
 #include "debug_p.h"
 
 #include <QApplication>
 #include <QDBusConnection>
 #include <QPushButton>
+#include <QProcess>
 #include <QString>
 
 #include <KStandardGuiItem>
 #include <KLocalizedString>
-#include <KProcess>
 
-#include <bluedevil/bluedevil.h>
+#include <BluezQt/InitManagerJob>
 
-BlueWizard::BlueWizard(const QUrl &url)
+BlueWizard::BlueWizard()
     : QWizard()
-    , m_device(0)
-    , m_manualPin(false)
+    , m_agent(new WizardAgent(this))
 {
     setWindowTitle(i18n("Bluetooth Device Wizard"));
 
     setOption(QWizard::IndependentPages, true);
 
-    if (url.host().length() == 17) {
-        setPreselectedAddress(url.host().replace(QLatin1Char('-'), QLatin1Char(':')).toLatin1());
-    }
-
-    if (url.fileName().length() == 36) {
-        setPreselectedUuid(url.fileName().toLatin1());
-    }
-
     setPage(Discover, new DiscoverPage(this));
-    setPage(NoPairing, new NoPairingPage(this));
-    setPage(Connect, new NoPairingPage(this));
+    setPage(Connect, new ConnectPage(this));
     setPage(LegacyPairing, new LegacyPairingPage(this));
     setPage(LegacyPairingDatabase, new LegacyPairingPageDatabase(this));
     setPage(KeyboardPairing, new KeyboardPairingPage(this));
     setPage(SSPPairing, new SSPPairingPage(this));
+    setPage(Success, new SuccessPage(this));
     setPage(Fail, new FailPage(this));
 
     QPushButton *backButton = new QPushButton(this);
@@ -84,18 +76,81 @@ BlueWizard::BlueWizard(const QUrl &url)
     setButtonText(QWizard::NextButton, i18nc("Action to go to the next page on the wizard", "Next"));
     setButtonText(QWizard::FinishButton, i18nc("Action to finish the wizard", "Finish"));
 
-    // First show, then do the rest
-    show();
-
-    if (!QDBusConnection::systemBus().registerObject(QStringLiteral("/wizardAgent"), qApp)) {
-        qCDebug(WIZARD) << "The dbus object can't be registered";
-    }
-
-    m_agent = new WizardAgent(qApp);
+    // Initialize BluezQt
+    m_manager = new BluezQt::Manager(this);
+    BluezQt::InitManagerJob *initJob = m_manager->init();
+    initJob->start();
+    connect(initJob, &BluezQt::InitManagerJob::result, this, &BlueWizard::initJobResult);
 }
 
-BlueWizard::~BlueWizard()
+BluezQt::DevicePtr BlueWizard::device() const
 {
+    return m_device;
+}
+
+void BlueWizard::setDevice(BluezQt::DevicePtr device)
+{
+    m_device = device;
+}
+
+void BlueWizard::setPin(const QString &pin)
+{
+    qCDebug(WIZARD) << "Setting pin:" << pin;
+
+    m_pin = pin;
+}
+
+QString BlueWizard::pin() const
+{
+    return m_pin;
+}
+
+WizardAgent *BlueWizard::agent() const
+{
+    return m_agent;
+}
+
+BluezQt::Manager *BlueWizard::manager() const
+{
+    return m_manager;
+}
+
+void BlueWizard::restartWizard()
+{
+    QProcess::startDetached(QStringLiteral("bluedevil-wizard"));
+
+    qApp->quit();
+}
+
+void BlueWizard::initJobResult(BluezQt::InitManagerJob *job)
+{
+    if (job->error()) {
+        qCWarning(WIZARD) << "Error initializing manager:" << job->errorText();
+        qApp->exit(1);
+        return;
+    }
+
+    qCDebug(WIZARD) << "Manager initialized";
+
+    // Make sure to register agent when bluetoothd starts
+    operationalChanged(m_manager->isOperational());
+    connect(m_manager, &BluezQt::Manager::operationalChanged, this, &BlueWizard::operationalChanged);
+
+    // Start discovery
+    static_cast<DiscoverPage*>(page(Discover))->startDiscovery();
+
+    // Only show wizard after init is completed
+    show();
+}
+
+void BlueWizard::operationalChanged(bool operational)
+{
+    if (operational) {
+        m_manager->registerAgent(m_agent);
+    } else {
+        // Attempt to start bluetoothd
+        BluezQt::Manager::startService();
+    }
 }
 
 void BlueWizard::done(int result)
@@ -105,77 +160,3 @@ void BlueWizard::done(int result)
     QWizard::done(result);
     qApp->exit(result);
 }
-
-Device* BlueWizard::device() const
-{
-    return m_device;
-}
-
-void BlueWizard::setDeviceAddress(const QByteArray& address)
-{
-    qCDebug(WIZARD) << "Device Address: " << address;
-    if (!Manager::self()->usableAdapter()) {
-        qCDebug(WIZARD) << "No usable adapter available";
-        return;
-    }
-
-    m_deviceAddress = address;
-    m_device = Manager::self()->usableAdapter()->deviceForAddress(m_deviceAddress);
-}
-
-QByteArray BlueWizard::deviceAddress() const
-{
-    return m_deviceAddress;
-}
-
-void BlueWizard::restartWizard()
-{
-    KProcess proc;
-    proc.setProgram(QStringLiteral("bluedevil-wizard"));
-    proc.startDetached();
-
-    qApp->quit();
-}
-
-void BlueWizard::setPin(const QByteArray& pinNum)
-{
-    qCDebug(WIZARD) << "Setting pin: :" << pinNum;
-    m_pin = pinNum;
-}
-
-void BlueWizard::setPin(const QString& pin)
-{
-    setPin(pin.toUtf8());
-}
-
-QByteArray BlueWizard::pin() const
-{
-    return m_pin;
-}
-
-void BlueWizard::setPreselectedUuid(const QByteArray& uuid)
-{
-    qCDebug(WIZARD) << "Preselect UUID: " << uuid;
-    m_preselectedUuid = uuid;
-}
-
-QByteArray BlueWizard::preselectedUuid() const
-{
-    return m_preselectedUuid;
-}
-
-void BlueWizard::setPreselectedAddress(const QByteArray& address)
-{
-    qCDebug(WIZARD) << "Preselected Address: " << address;
-    m_preselectedAddress = address;
-}
-
-QByteArray BlueWizard::preselectedAddress() const
-{
-    return m_preselectedAddress;
-}
-
-WizardAgent* BlueWizard::agent() const
-{
-    return m_agent;
-}
