@@ -24,39 +24,39 @@
 #define KEYBOARDPAIRING_H
 
 #include "ui_keyboardpairing.h"
+
 #include <QWizardPage>
 
+namespace BluezQt
+{
+    class PendingCall;
+}
+
 class BlueWizard;
 class KPixmapSequenceOverlayPainter;
 
-namespace BlueDevil {
-    class Device;
-    class Adapter;
-}
-
-using namespace BlueDevil;
-
 class KeyboardPairingPage : public QWizardPage, Ui::KeyboardPairing
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    KeyboardPairingPage(BlueWizard* parent = 0);
+    explicit KeyboardPairingPage(BlueWizard *parent = 0);
 
-    virtual void initializePage();
-    virtual bool validatePage();
-    virtual int nextId() const;
+    int nextId() const Q_DECL_OVERRIDE;
+    void initializePage() Q_DECL_OVERRIDE;
 
-public Q_SLOTS:
+private Q_SLOTS:
+    void setPairableFinished(BluezQt::PendingCall *call);
+    void pairingFinished(BluezQt::PendingCall *call);
     void pinRequested(const QString &pin);
-    void pairedChanged(bool paired);
 
 protected:
-    QList <QWizard::WizardButton> wizardButtonsLayout() const;
+    QList<QWizard::WizardButton> wizardButtonsLayout() const;
 
 private:
-    BlueWizard                    *m_wizard;
+    BlueWizard *m_wizard;
     KPixmapSequenceOverlayPainter *m_working;
+    bool m_success;
 };
 
 #endif // KEYBOARDPAIRING_H
