@@ -23,39 +23,37 @@
 #ifndef LEGACYPAIRINGDATABASE_H
 #define LEGACYPAIRINGDATABASE_H
 
-#include "ui_nopairing.h"
+#include "ui_connect.h"
+
 #include <QWizardPage>
 
-class BlueWizard;
-class KPixmapSequenceOverlayPainter;
-
-namespace BlueDevil {
-    class Device;
-    class Adapter;
+namespace BluezQt
+{
+    class PendingCall;
 }
 
-using namespace BlueDevil;
+class BlueWizard;
 
-class LegacyPairingPageDatabase : public QWizardPage, Ui::NoPairing
+class LegacyPairingPageDatabase : public QWizardPage, Ui::Connect
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    LegacyPairingPageDatabase(BlueWizard* parent = 0);
+    explicit LegacyPairingPageDatabase(BlueWizard *parent = 0);
 
-    virtual void initializePage();
-    virtual bool validatePage();
-    virtual int nextId() const;
+    int nextId() const Q_DECL_OVERRIDE;
+    void initializePage() Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
-    void pairedChanged(bool paired);
+    void setPairableFinished(BluezQt::PendingCall *call);
+    void pairingFinished(BluezQt::PendingCall *call);
 
 protected:
-    QList <QWizard::WizardButton> wizardButtonsLayout() const;
+    QList<QWizard::WizardButton> wizardButtonsLayout() const;
 
 private:
-    BlueWizard                    *m_wizard;
-    KPixmapSequenceOverlayPainter *m_working;
+    BlueWizard *m_wizard;
+    bool m_success;
 };
 
 #endif // LEGACYPAIRINGDATABASE_H
